#!/bin/sh
# Name : diag_eagle_usb.sh
# Goal : diagnostic script for adiusbadsl
# Author : Benoit Audouard aka baud123 (baud at magic dot fr)
# Description : identifie les elements permettant un diagnostic
#       type de systeme, verification de l'install
#       verification bon fonctionnement modem
#	verification bon fonctionnement couche reseau
# ce script s'adapte a la version 1.0.4e des drivers et au-dessus
# il doit etre lance sous root
# Availability : see http://baud123.free.fr/eagle/
# Version : 0.5 20030922
VERSION_DIAG="v0.6"

# todo
# - ajouter un filtre sur /var/log/messages (mots cle grep -iE: pppd, usb, adi, ...)
# - obtenir un numero de version du driver eagle-usb (meme celles de dev)
# - obtenir le type de connexion (degroupe ok, Free/9Tel/...)
# - traduire completement les commentaires en anglais

# done
# 0.5 take into account eagle-cvs and eagle-1.0.4
# 0.6 correction anomaly eagleusb.conf => eagle-usb.conf (ballot)

# INIT
# initialisation des variables globales
# date au format YYYYMMDDHHmmss
TIME_STAMP=`date +"%Y""%m""%d""%H""%M""%S"`

# Paths
LOG_FILE=/var/log/eagle_diag_${TIME_STAMP}.txt

SYSCONF_FILE=/var/lock/subsys/adiusbadsl # for service in 1.0.4e
#SYSCONF_FILE=/etc/sysconfig/adiusbadsl
#EAGLEDIR=/usr/local/eagleusb
EAGLECONF=/etc/eagle-usb.conf
EAGLE_VERSION="1.0.4"
EAGLE_STAT=showstat
# v1.0.5pre1cvs : directory change
if [ -f /etc/eagle-usb/eagle-usb.conf ] ; then
	EAGLECONF=/etc/eagle-usb/eagle-usb.conf
	EAGLE_VERSION="1.0.5pre1cvs"
	EAGLE_STAT=eaglestat
fi

# Strings:
OPERSTR="Modem is operational"
IP_FREE="213.228.0.42"
URL_FREE="www.free.fr"

# GET_INFO
# groupe ou degroupe ? unlucky ou lucky ?
# by default NON DEGROUPE (Free)
FREE_DEGROUPE=0
if [ -f ${EAGLECONF} ] ; then
	if [ "X"`cat ${EAGLECONF}|grep DEGROUPE` == "X""DEGROUPE=0" ] ; then
		FREE_DEGROUPE=0
	else
		FREE_DEGROUPE=1
	fi
fi

# Mandrake et Red-Hat gerent les rpm
RPM_EXIST=0 ## trouver le test qui va bien...
if [ -f /etc/mandrake-release ] ; then
	DISTRIB="mdk"
	RPM_EXIST=1
else
	DISTRIB="other"
fi
CMDECHO="echo"

# START DIAG
${CMDECHO} "Lancement du diagnostic ${VERSION_DIAG}, veuillez patienter"
${CMDECHO} "Vous pouvez lancer dans un autre terminal tail -f ${LOG_FILE}"
${CMDECHO} "Diagnostic ${VERSION_DIAG} du driver eagleusb le ${TIME_STAMP}" >> ${LOG_FILE}
tail -f ${LOG_FILE} 2>/dev/null &
PID_TAIL=$!

# System Information 
${CMDECHO} "* System Information" >> ${LOG_FILE}
uname -a >> ${LOG_FILE}
if [ ${DISTRIB} == "mdk" ] ; then
	cat /etc/mandrake-release >> ${LOG_FILE}
fi
cat /proc/version >> ${LOG_FILE}
gcc --version |grep -i gcc >> ${LOG_FILE}

# Verify dependances of eagle-usb driver on source
# if a binary RPM is used, no need for this
# si c'etait un RPM qui etait livre, il n'y aurait pas besoin de cela...
${CMDECHO} "* Dependances" >> ${LOG_FILE}
if [ ${RPM_EXIST} -eq 1 ] ; then
	rpm -q kernel-source >> ${LOG_FILE} 2>&1
	rpm -q patch >> ${LOG_FILE} 2>&1
	rpm -q slocate >> ${LOG_FILE} 2>&1
else
	${CMDECHO} "Verifier dependances a la main (kernel-source...)" >> ${LOG_FILE}
	#${CMDECHO} "Verify dependances on source by hand (kernel-source...)" >> ${LOG_FILE}
fi

# Another verification (which source is used ?)
# deux verifs valent mieux qu'une (3 en comptant le uname)
ls -l /usr/src/ | grep -i linux >> ${LOG_FILE} 2>&1

# Verify modules configuration
# Verifie config des modules
${CMDECHO} "* Kernel config : usb modules" >> ${LOG_FILE}
lsmod | grep usb >> ${LOG_FILE}

# valid for 1.0.4e
$CMDECHO "* service started ? (info for 1.0.4e)" >> ${LOG_FILE}
if [ -f $SYSCONF_FILE ] ; then
	$CMDECHO "[ Oui ]" >> ${LOG_FILE}
else
	$CMDECHO "[ Non ]" >> ${LOG_FILE}
fi
$CMDECHO "* module loaded ?" >> ${LOG_FILE}
if lsmod | grep -q "adiusbadsl" ; then
	$CMDECHO "[ OK ]" >> ${LOG_FILE}
else
	$CMDECHO "[ Erreur ]" >> ${LOG_FILE}
fi
$CMDECHO "* modem operational ?" >> ${LOG_FILE}
if ${EAGLE_STAT} | grep -q "Modem is operational" ; then
	$CMDECHO "[ OK ]" >> ${LOG_FILE}
else
	$CMDECHO "[ Erreur ]" >> ${LOG_FILE}
fi
# un petit showstat tout de meme (donne l'attenuation pour les deconnexions)
# provide showstat result (gives attenuation)
# identify VPI/VCI in decimal
${EAGLE_STAT} >> ${LOG_FILE}

# si le service est lance (faut un minimum d'effort tout de meme)
# commente : n'a plus l'air de fonctionner avec Mandrake 9.2 ?
#if [ -f $SYSCONF_FILE ] ; then
	SERVICE_CONNEXION=0 # le service de connexion est operationnel ?
	# ce serait pas mal d'avoir plus d'info que groupe/degroupe
	# maintenant ya 9telecom, les anglais, ...
	if [ ${FREE_DEGROUPE} -eq 0 ] ; then
		$CMDECHO "* Config eagle : non degroupe Free" >> ${LOG_FILE}
		$CMDECHO "* pppd lance ?" >> ${LOG_FILE}
		if [ `pidof pppd` ] ; then
			$CMDECHO "[ OK ]" >> ${LOG_FILE}
			SERVICE_CONNEXION=1
		else
			$CMDECHO "[ Erreur ]" >> ${LOG_FILE}
		fi
		# ajouter tests divers lie au non degroupe
		# add tests related to "non dgroupe"
	else
		$CMDECHO "* Config eagle : degroupe Free" >> ${LOG_FILE}
		$CMDECHO "* dhcpclient lance ?" >> ${LOG_FILE}
		SERVICE_CONNEXION=1
		# tests divers lie au degroupe free
		# tests related to "Free degroupe"
		# pppd ne doit pas etre lance
		# pppd should not be launched
		if [ `pidof pppd` ] ; then
			$CMDECHO "[ Erreur pppd lance en degroupe ]" >> ${LOG_FILE}
		fi
	fi
	if [ ${SERVICE_CONNEXION} -eq 1 ] ; then
		$CMDECHO "Un service de connexion est lance" >> ${LOG_FILE}
	fi
	# bah on fait quand meme ces tests 
	# (avec IP fixe, il ne devrait pas yavoir besoin de dhcpclient...)
	# ya des infos sur le LAN que l'utilisateur devrait cacher
	$CMDECHO "/etc/resolv.conf doit contenir les DNS" >> ${LOG_FILE}
	# debug : verifier que ca marche si c'est un lien
	if [ -f /etc/resolv.conf ] ; then
		cat /etc/resolv.conf >> ${LOG_FILE}
	fi
	ifconfig -a >> ${LOG_FILE}
	route -n >> ${LOG_FILE}
		
	$CMDECHO "* ping vers IP ?        " >> ${LOG_FILE}
	/bin/ping -n -q -c 1 -w 5 ${IP_FREE} 1>/dev/null 2>/dev/null
	if [ $? = 0 ] ; then
		$CMDECHO "[ OK ]" >> ${LOG_FILE}
	else
		$CMDECHO "[ Erreur ]" >> ${LOG_FILE}
	fi
	$CMDECHO "* test rsolution DNS ? " >> ${LOG_FILE}
	/bin/ping -n -q -c 1 -w 5 ${URL_FREE} 1>/dev/null 2>/dev/null
	if [ $? = 0 ] ; then
		$CMDECHO "[ OK ]" >> ${LOG_FILE}
	else
		$CMDECHO "[ Erreur ]" >> ${LOG_FILE}
	fi
#fi
sleep 2
kill ${PID_TAIL} >/dev/null 2>&1

$CMDECHO "Le diagnostic est disponible dans le fichier ${LOG_FILE}"
$CMDECHO "Pensez a le trier et a enlever les informations sensibles"
exit 0

